@@ -1,6 +1,7 @@
 import sys
+from typing import Tuple
 
-from je_auto_control.utils.exception.exception_tag import osx_import_error
+from je_auto_control.utils.exception.exception_tags import osx_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
 
 if sys.platform not in ["darwin"]:
@@ -9,7 +10,7 @@ if sys.platform not in ["darwin"]:
 import Quartz
 
 
-def size():
+def size() -> Tuple[int, int]:
     """
     get screen size
     """
